@@ -2,7 +2,6 @@ package com.typesafe.netty.http;
 
 import akka.actor.ActorSystem;
 import akka.japi.function.Function;
-import akka.stream.ActorMaterializer;
 import akka.stream.Materializer;
 import akka.stream.javadsl.Flow;
 import com.typesafe.netty.HandlerPublisher;
@@ -16,7 +15,6 @@ import io.netty.channel.socket.SocketChannel;
 import io.netty.channel.socket.nio.NioServerSocketChannel;
 import io.netty.channel.socket.nio.NioSocketChannel;
 import io.netty.handler.codec.http.*;
-import org.omg.CORBA.TIMEOUT;
 import org.reactivestreams.Processor;
 import org.testng.annotations.AfterClass;
 import org.testng.annotations.AfterMethod;
@@ -344,7 +342,7 @@ public class HttpStreamsTest {
     public void startEventLoop() {
         eventLoop = new NioEventLoopGroup();
         actorSystem = ActorSystem.create();
-        materializer = ActorMaterializer.create(actorSystem);
+        materializer = Materializer.matFromSystem(actorSystem);
         helper = new HttpHelper(materializer);
     }
 
